@@ -15,12 +15,9 @@ class init_anim:
     """
     Sets up the global animation information such speed up and global scale
 
-
-    Arguments:
-    ----------
-        :param: `t` :type: `np.ndarray`, contains the time information that corresponds with the six degrees of freedom data 
-        :param: `speed_up` :type: `float`, the "real time speed up" or the ratio of the duration of the data to the duration of the animation 
-        :param: ` scale` :type: `float`, global physical scale factor of the animation, i.e., .1 will reduce everything to be 1/10th its original size
+    :param np.ndarray t: contains the time information that corresponds with the six degrees of freedom data 
+    :param: float speed_up: the 'real time speed up' or the ratio of the duration of the data to the duration of the animation 
+    :param float scale: global physical scale factor of the animation, i.e., .1 will reduce everything to be 1/10th its original size
     """
     def __init__(self, t, speed_up, scale):
 
@@ -52,13 +49,12 @@ class ref_frame:
     In blender, this takes the form of an Empty object.
 
 
-    Arguments:
-        :param: `name` :type: `str`, the Blender object name of the reference frame
-        :param: `parent` :type: `bpy.data.object`, the Blender object parent of this reference frame 
-        :param: `anim` :class:`bpsci.core.init_anim`, class object that was used to initialize the animation
+    :param str name: the Blender object name of the reference frame
+    :param bpy.data.object parent: the Blender object parent of this reference frame 
+    :param anim: class object that was used to initialize the animation
+    :type anim: :class:`bpsci.core.anim`
     
-    Attributes:
-    -----------
+
     """
     def __init__(self, name, parent, anim):
 
@@ -99,10 +95,10 @@ class ref_frame:
 
         Arguments:
         ----------
-            :param: `quat` :type: `np.ndarray`, an numpy array of one quaternion
-            :param: `x` :type: `float`, the x position 
-            :param: `y` :type: `float`, the y position 
-            :param: `z` :type: `float`, the z position 
+            :param np.ndarray quat: an numpy array of one quaternion
+            :param float x: the x position 
+            :param float y: the y position 
+            :param float z: the z position 
 
         """
         if not(quat is None):
@@ -125,13 +121,10 @@ class ref_frame:
 
         May be useful for continually offsetting the reference frame from the parent object (i.e. for center of mass of principal axes offset for changing mass/distribution)
 
-
-        Arguments:
-        ----------
-            :param: `quat` :type: `np.ndarray`, an numpy array of quaternions over time
-            :param: `x` :type: `np.ndarray`, the x position over time
-            :param: `y` :type: `np.ndarray`, the y position over time
-            :param: `z` :type: `np.ndarray`, the z position over time
+        :param np.ndarray quat: an numpy array of quaternions over time
+        :param np.ndarray x: the x position over time
+        :param np.ndarray y: the y position over time
+        :param np.ndarray z: the z position over time
 
         """
 
@@ -165,14 +158,14 @@ class dyn_obj:
     """
     The main building block of all dynamic visualizations 
 
-    Arguments:
-    ----------
-        :param: `obj: :type` `bpy.data.object`, the Blender object that will be animated
-        :param: `pa: :type` `np.ndarray`, the offset of the principal axes specified by the :param: ` euler_type:
-        :param: `euler_type` :type: `str`. the Euler angle order (i.e. 'xyz' for 1,2,3 or 'zxz' for 3,1,3)
-        :param: `parent` :type: `bpy.data.object`, the Blender object parent of the original object 
-        :param: `anim` :class: `bpsci.core.init_anim`, class object that was used to initialize the animation
 
+    :param bpy.data.object obj: the Blender object that will be animated
+    :param np.ndarray pa: the offset of the principal axes specified by the :param: ` euler_type:
+    :param str euler_type: the Euler angle order (i.e. 'xyz' for 1,2,3 or 'zxz' for 3,1,3)
+    :param bpy.data.object parent: the Blender object parent of the original object 
+    :param anim: class object that was used to initialize the animation
+    :type anim: :class:`bpsci.core.init_anim`
+        
     """
     def __init__(self, obj, pa, euler_type, parent, anim):
         
@@ -218,12 +211,11 @@ class dyn_obj:
         """
         Animates a :class:`~bpsci.core.dyn_obj` in the full six degrees of freedom
 
-        Arguments:
-            :param: `x_list` :type: `np.ndarray`, a numpy array of the x position over time
-            :param: `y_list` :type: `np.ndarray`, a numpy array of the y position over time
-            :param: `z_list` :type: `np.ndarray`. a numpy array of the z position over time
-            :param: `quat_list` :type: `np.ndarray` or None, a numpy array of the rotational quaternion over time. Can be passed None if rotation is ignored.
-            """
+        :param np.ndarray x_list: a numpy array of the x position over time
+        :param np.ndarray y_list: a numpy array of the y position over time
+        :param np.ndarray z_list: a numpy array of the z position over time
+        :param np.ndarray quat_list: a numpy array of the quaternion over time. Can be passed None if rotation is ignored.
+        """
 
         self.pa_axes.dynamic_6DOF(quat_list, None, None, None)
         self.non_rot.dynamic_6DOF(None, x_list, y_list, z_list)
@@ -232,15 +224,11 @@ class dyn_obj:
         """
         Creates a static or dynamic positional streamline for a :class:`~bpsci.core.dyn_obj`
 
-        Arguments:
-        ----------
-            :param: `staticity` :type: `str`, a string (either 'static' or 'dynamic') that specifies whether the the streamline is animated over time
-            :param: `int_x` :type: `np.ndarray`, a numpy array of the x position over time
-            :param: `int_y` :type: `np.ndarray`, a numpy array of the y position over time
-            :param: `int_z` :type: `np.ndarray`, a numpy array of the z position over time
+        :param str staticity: a string (either 'static' or 'dynamic') that specifies whether the the streamline is animated over time
+        :param np.ndarray int_x: a numpy array of the x position over time
+        :param np.ndarray int_y: a numpy array of the y position over time
+        :param np.ndarray int_z: a numpy array of the z position over time
         
-        Attributes:
-        -----------
         """
 
 
@@ -290,14 +278,14 @@ class dyn_vec:
     """
     Initializes a dynamic vector`
 
-    Arguments:
-    ----------
-        :param: `parent` :type: `bpy.data.object`, the Blender object the vector is associated with
-        :param: `name` :type: `str`, the Blender object name of the vector ('_vector' will be appended to this name)
-        :param: `scale_mag` :type: `float`, the scaling factor of the vector's magnitude axis (purely aesthetic)
-        :param: `scale_off` :type: `float`, the scaling factor of the vector's off-axes (purely aesthetic)
-        :param: `offset` :type: `tuple`, offset of vector from the parent object (purely aesthetic)
-        :param: `anim` :class:`bpsci.core.init_anim`, class object that was used to initialize the animation
+
+    :param bpy.data.object parent: the Blender object the vector is associated with
+    :param str name: the Blender object name of the vector ('_vector' will be appended to this name)
+    :param float scale_mag: the scaling factor of the vector's magnitude axis (purely aesthetic)
+    :param float scale_off: the scaling factor of the vector's off-axes (purely aesthetic)
+    :param tuple[float] offset: offset of vector from the parent object (purely aesthetic)
+    :param anim: class object that was used to initialize the animation
+    :type anim: :class:`bpsci.core.anim`
 
     """
     def __init__(self, parent, name, scale_mag, scale_off, offset, anim):
@@ -337,14 +325,10 @@ class dyn_vec:
         """
         Animates a dynamic vector
 
-        Arguments:
-        ----------
-            :param: `x` :type: `np.ndarray`, a numpy array of the x component over time
-            :param: `y` :type: `np.ndarray`,  a numpy array of the y component over time
-            :param: `z` :type: `np.ndarray`, a numpy array of the z component over time
+        :param np.ndarray x: a numpy array of the x component over time
+        :param np.ndarray y: a numpy array of the y component over time
+        :param np.ndarray z: a numpy array of the z component over time
 
-        Attributes:
-        -----------
         """
 
         frames = self.frames
@@ -390,15 +374,15 @@ class anim_text:
     """
     Creates animated text
 
-    Arguments:
-    ----------
-        :param: `name` :type: `str`, the Blender object name of the text ('_text' will be appended to this name)
-        :param: `parent` :type: `bpy.data.object`, the Blender object parent of this text 
-        :param: `anim` :class:`bpsci.core.init_anim`, class object that was used to initialize the animation
-        :param: `data` :type: `np.ndarray`, the data to be displayed (same length as the number of animated frames)
-        :param: `label` :type: `str`, a label to append to the text (if no label is desired, pass '')
-        :param: `fix_place` int, the number of decimal places to fix the text to
-        :param: `if_str` bool, whether or not the data is a numerical or string vector. Currently only numerical vectors are supported.
+
+        :param str name: the Blender object name of the text ('_text' will be appended to this name)
+        :param bpy.data.object parent: the Blender object parent of this text 
+        :param anim: class object that was used to initialize the animation
+        :type anim: :class:`bpsci.core.anim`
+        :param np.ndarray data: the data to be displayed (same length as the number of animated frames)
+        :param str label: a label to append to the text (if no label is desired, pass '')
+        :param int fix_place: the number of decimal places to fix the text to
+        :param bool if_str: whether or not the data is a numerical or string vector. Currently only numerical vectors are supported.
 
     """
     def __init__(self, name, parent, anim, data, label, fix_place, if_str):
